Schema to store an error or exception recorded by Faulty.
It stores a kind, reason and source code location to generate a unique fingerprint that can be used to avoid duplicates.
The fingerprint includes a normalized version of the error reason to ensure
proper grouping of similar errors while separating different error types.
See Faulty.Fingerprint for the fingerprinting algorithm details.
Summary
Functions
Returns if the Error has information of the source or not.